@@ -34,7 +34,7 @@ our @EXPORT = qw(
 	CS_INT_MIN
 );
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -92,7 +92,8 @@ sub DESTROY {
     my $vars = $self->{_vars};
 
     for my $v (@$vars) {
-	$v->_invalidate($v);
+	# we must check existence of variable for global destruction.
+	$v->_invalidate($v) if ($v);
     }
 
     Algorithm::CP::IZ::cs_end();
